@@ -174,7 +174,7 @@ extern "C" {
 
 /* The version numbers should be updated with every release! **/
 #define PROJ_VERSION_MAJOR 9
-#define PROJ_VERSION_MINOR 6
+#define PROJ_VERSION_MINOR 7
 #define PROJ_VERSION_PATCH 0
 
 /* Note: the following 3 defines have been introduced in PROJ 8.0.1 */
@@ -675,6 +675,36 @@ double PROJ_DLL proj_xyz_dist(PJ_COORD a, PJ_COORD b);
  * ellipsoid */
 PJ_COORD PROJ_DLL proj_geod(const PJ *P, PJ_COORD a, PJ_COORD b);
 
+/**
+ * @brief Solves the direct geodesic problem for given projection ellipsoid
+ *
+ * @param P
+ *      Transformation or CRS object
+ *
+ * @param a
+ *      Coordinate of first point. The coordinates needs to be given as
+ * longitude and latitude in radians. Note that the axis order of the `P` object
+ * is not taken into account in this function, so even though a CRS object comes
+ * with axis ordering latitude/longitude coordinates used in this function
+ * should be reordered as longitude latitude.
+ *
+ * @param azimuth
+ *      Initial azimuth from first point to second point in radians, measured
+ *      clockwise from true north
+ *
+ * @param distance
+ *      Geodesic distance from the starting point to the destination, in meters
+ *
+ * @return
+ *      `PJ_COORD` where the first value is the longitude in radians, second
+ * value is latitude in radians and third value is forward azimuth at second
+ * point in radians. The fourth coordinate value is unused.
+ *
+ * @see proj_geod() for solving the inverse geodesic problem.
+ */
+PJ_COORD PROJ_DLL proj_geod_direct(const PJ *P, PJ_COORD a, double azimuth,
+                                   double distance);
+
 /* PROJ error codes */
 
 /** Error codes typically related to coordinate operation initialization
